==> pgmarket-1.5.2.tar.gz: pgmarket-1.5.2/locale/it/global-admin.inc.php <==
<?php

/* (c) 2000, 2001 Marco Pratesi <pratesi@telug.it> */
/* (c) 2000 Fabio Molinari <fabio.m@mclink.it> */
/* (c) 2001 Andrew Stubbs <andrews@stusoft.com> */

$t->set_var(array(

"Insufficient_Privileges" => "Diritti insufficienti",
"Administration" => "Amministrazione",
"admin_footer_message" => "$CFG->myname" . " \"<i>Commercio elettronico - Electronic Store</i>\"",
"Save_Changes" => "Salva modifiche",
"Import_Button_Label" => "Importa",
"Add_Subcategory" => "Aggiungi sottocategoria",
"Products_Management" => "Amministrazione dei prodotti",
"Add_Product" => "Aggiungi prodotto",
"P_Add_Product" => "[+P] Aggiungi prodotto",
"Import_Products" => "Importa prodotti",
"Import_Images" => "Importa immagini",
"Delete_Product" => "Elimina prodotto",
"Edit_Product" => "Modifica prodotto",
"Edit_this_product" => "Modifica questo prodotto",
"Special_Level" => "Livello",
"Special_Flag" => "Prodotto Speciale",
"Delete_Current_Image" => "Elimina Immagine Attuale (lascia il prodotto senza immagine)",
"Import_Images_Button_Label" => "Importa Immagini",
"Brands_Management" => "Amministrazione delle marche",
"B_Add_Brand" => "[+M] Aggiungi marca",
"Import_Brands" => "Importa marche",
"Edit_this_brand" => "Modifica questa marca",
"Brand_reset_for_products" => "La marca &egrave; stata azzerata per i prodotti di tale marca",
"Add_Brand" => "Aggiungi marca",
"Categories_Management" => "Amministrazione delle categorie",
"C_Add_Category" => "[+C] Aggiungi categoria",
"Import_Categories" => "Importa categorie",
"Edit_this_category" => "Modifica questa categoria",
"Add_a_subcategory_under" => "Aggiungi una sottocategoria di",
"All_the_products_and_sub_categories_belonging_to" => "Tutti i prodotti e le sottocategorie appartenenti a",
"have_been_reassigned_to_male_plural" => "sono stati riassegnati a",
"IVA_Management" => "Amministrazione dei valori di " . $IVA,
"I_Add_IVA" => "[+I] Aggiungi percentuale " . $IVA,
"Import_IVA" => "Importa percentuali " . $IVA,
"Edit_this_IVA" => "Modifica questa percentuale di " . $IVA,
"Add_IVA" => "Aggiungi " . $IVA,
"The_IVA_Percentage" => "La percentuale di " . $IVA,
"IVA_reset_for_products" => "La percentuale di " . $IVA . " &egrave; stata azzerata per i prodotti con tale " . $IVA,
"Cust_Info" => "Info cliente",
"Orders_States_Management" => "Gestione stati degli ordini",
"Delete_this_order" => "Cancella questo ordine",
"Edit_this_order" => "Modifica questo ordine",
"S_Add_Order_State" => "[+S] Aggiungi stato",
"Import_Orders_States" => "Importa stati",
"Edit_this_order_state" => "Modifica questo stato",
"Add_Order_State" => "Aggiungi stato",
"The_Order_State" => "Lo stato",
"The_order_state" => "Lo stato",
"Order_State_reset_for_orders" => "Lo stato degli ordini &egrave; stato azzerato per tutti gli ordini in tale stato",
"Add_a_product_under" => "Aggiungi un prodotto a",
"currently_its_name_is_male_singular" => "attualmente si chiama",
"currently_its_name_is_female_singular" => "attualmente si chiama",
"currently_its_value_is_female_singular" => "attualmente vale",
"Users_Management" => "Gestione degli utenti",
"Users" => "Utenti",
"USERS" => "UTENTI",
"U_Add_User" => "[+U] Aggiungi Persona Fisica",
"U_Add_Company_User" => "[+U] Aggiungi Azienda",
"U_Import_Users" => "Importa utenti",
"Data_handl" => "Tratt. dati",
"Advert" => "Acc. pubbl.",
"Reset_password_for" => "Reinizializza la password di",
"Change_password_for" => "Modifica la password di",
"Edit_this_user" => "Modifica questo utente",
"Email_this_user" => "Scrivi a questo utente",
"Add_User" => "Aggiungi utente",
"The_user" => "L'utente",
"data_have_been_updated" => "i dati sono stati modificati",
"Privilege" => "Privilegio",
"Auth_data_handling_az" => "Aut. tratt. dati az.",
"Auth_data_handling_pf" => "Aut. tratt. dati pers.",
"Accept_advert_material" => "Disp. a ricevere mat. p.",
"Authorization_for_data_handling_az" => "Autorizzazione al trattamento dei dati aziendali",
"Authorization_for_data_handling_pf" => "Autorizzazione al trattamento dei dati personali",
"Acceptance_of_advertising_material" => "Disponibilit&agrave; a ricevere materiale pubblicitario",
"Our_Notes" => "Nostre Annotazioni",
"Registration_Date" => "Data iscr.",
"_Import_File" => "File da Importare",
"End_Import" => "Import Terminato.",

));

?>

==> pgmarket-1.5.3.tar.gz: pgmarket-1.5.3/locale/it/global-admin.inc.php <==
<?php

/* (c) 2000, 2001 Marco Pratesi <pratesi@telug.it> */
/* (c) 2000 Fabio Molinari <fabio.m@mclink.it> */
/* (c) 2001 Andrew Stubbs <andrews@stusoft.com> */

$t->set_var(array(

"Insufficient_Privileges" => "Diritti insufficienti",
"Administration" => "Amministrazione",
"admin_footer_message" => "$CFG->myname" . " \"<i>Commercio elettronico - Electronic Store</i>\"",
"Languages" => "Linguaggi",
"Add_Lang" => "Aggiungi lingua",
"L_Add_Lang" => "[+L] Aggiungi lingua",
"Language" => "Lingua",
"The_language" => "La lingua",
"Choose" => "Scegli",
"Selected_Internationalization_Language" => "Lingua di internazionalizzazione scelta",
"Internationalization" => "Internazionalizzazione",
"internationalization_deleted" => "internazionalizzazione eliminata",
"Save_Changes" => "Salva modifiche",
"Import_Button_Label" => "Importa",
"Add_Subcategory" => "Aggiungi sottocategoria",
"Products_Management" => "Amministrazione dei prodotti",
"Products_Management_i18n" => "Amministrazione dei prodotti - I18N",
"Add_Product" => "Aggiungi prodotto",
"P_Add_Product" => "[+P] Aggiungi prodotto",
"Import_Products" => "Importa prodotti",
"Import_Images" => "Importa immagini",
"Delete_Product" => "Elimina prodotto",
"Edit_Product" => "Modifica prodotto",
"Edit_this_product" => "Modifica questo prodotto",
"Special_Level" => "Livello",
"Special_Flag" => "Prodotto Speciale",
"Delete_Current_Image" => "Elimina Immagine Attuale (lascia il prodotto senza immagine)",
"Import_Images_Button_Label" => "Importa Immagini",
"Brands_Management" => "Amministrazione delle marche",
"B_Add_Brand" => "[+M] Aggiungi marca",
"Import_Brands" => "Importa marche",
"Edit_this_brand" => "Modifica questa marca",
"Brand_reset_for_products" => "La marca &egrave; stata azzerata per i prodotti di tale marca",
"Add_Brand" => "Aggiungi marca",
"Colors_Management" => "Amministrazione dei colori",
"C_Add_Color" => "[+C] Aggiungi colore",
"Import_Colors" => "Importa colori",
"Edit_this_color" => "Modifica questo colore",
"Color_reset_for_products" => "Il colore &egrave; stata azzerato per i prodotti di tale colore",
"Add_Color" => "Aggiungi colore",
"Categories_Management" => "Amministrazione delle categorie",
"Categories_Management_i18n" => "Amministrazione delle categorie - I18N",
"C_Add_Category" => "[+C] Aggiungi categoria",
"Import_Categories" => "Importa categorie",
"Edit_this_category" => "Modifica questa categoria",
"Add_a_subcategory_under" => "Aggiungi una sottocategoria di",
"All_the_products_and_sub_categories_belonging_to" => "Tutti i prodotti e le sottocategorie appartenenti a",
"have_been_reassigned_to_male_plural" => "sono stati riassegnati a",
"IVA_Management" => "Amministrazione dei valori di " . $IVA,
"I_Add_IVA" => "[+I] Aggiungi percentuale " . $IVA,
"Import_IVA" => "Importa percentuali " . $IVA,
"Edit_this_IVA" => "Modifica questa percentuale di " . $IVA,
"Add_IVA" => "Aggiungi " . $IVA,
"The_IVA_Percentage" => "La percentuale di " . $IVA,
"IVA_reset_for_products" => "La percentuale di " . $IVA . " &egrave; stata azzerata per i prodotti con tale " . $IVA,
"Cust_Info" => "Info cliente",
"Orders_States_Management" => "Gestione stati degli ordini",
"Delete_this_order" => "Cancella questo ordine",
"Edit_this_order" => "Modifica questo ordine",
"S_Add_Order_State" => "[+S] Aggiungi stato",
"Import_Orders_States" => "Importa stati",
"Edit_this_order_state" => "Modifica questo stato",
"Add_Order_State" => "Aggiungi stato",
"The_Order_State" => "Lo stato",
"The_order_state" => "Lo stato",
"Order_State_reset_for_orders" => "Lo stato degli ordini &egrave; stato azzerato per tutti gli ordini in tale stato",
"Add_a_product_under" => "Aggiungi un prodotto a",
"currently_its_name_is_male_singular" => "attualmente si chiama",
"currently_its_name_is_female_singular" => "attualmente si chiama",
"currently_its_value_is_female_singular" => "attualmente vale",
"Users_Management" => "Gestione degli utenti",
"Users" => "Utenti",
"USERS" => "UTENTI",
"U_Add_User" => "[+U] Aggiungi Persona Fisica",
"U_Add_Company_User" => "[+U] Aggiungi Azienda",
"U_Import_Users" => "Importa utenti",
"Data_handl" => "Tratt. dati",
"Advert" => "Acc. pubbl.",
"Reset_password_for" => "Reinizializza la password di",
"Change_password_for" => "Modifica la password di",
"Edit_this_user" => "Modifica questo utente",
"Email_this_user" => "Scrivi a questo utente",
"Add_User" => "Aggiungi utente",
"The_user" => "L'utente",
"data_have_been_updated" => "i dati sono stati modificati",
"Privilege" => "Privilegio",
"Auth_data_handling_az" => "Aut. tratt. dati az.",
"Auth_data_handling_pf" => "Aut. tratt. dati pers.",
"Accept_advert_material" => "Disp. a ricevere mat. p.",
"Authorization_for_data_handling_az" => "Autorizzazione al trattamento dei dati aziendali",
"Authorization_for_data_handling_pf" => "Autorizzazione al trattamento dei dati personali",
"Acceptance_of_advertising_material" => "Disponibilit&agrave; a ricevere materiale pubblicitario",
"Our_Notes" => "Nostre Annotazioni",
"Registration_Date" => "Data iscr.",
"_Import_File" => "File da Importare",
"End_Import" => "Import Terminato.",

));

?>
